/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package nl.cloudfarming.client.geoviewer.jxmap.map;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.CoordinateSequence;
import com.vividsolutions.jts.geom.LinearRing;
import com.vividsolutions.jts.geom.Polygon;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;
import nl.cloudfarming.client.geoviewer.SingleObjectLayer;
import nl.cloudfarming.client.geoviewer.render.DrawingRenderer;
import nl.cloudfarming.client.geoviewer.render.PolygonDrawingRenderer;
import org.jdesktop.swingx.JXMapViewer;
import org.openide.util.NbBundle;

/**
 *
 * @author johan
 */
@NbBundle.Messages({"# {0} - name of the object being edited", "PolygonDrawingContext.description=creating geometry for {0}"})
class PolygonDrawingContext extends AbstractLineDrawingContext {
    private SingleObjectLayer layer;

    public PolygonDrawingContext(SingleObjectLayer layer, JXMapViewer mapViewer) {
        super(mapViewer);
        this.layer = layer;
    }

    @Override
    public boolean canFinish() {
        // are there enough points to create a polygon?
        if (coords.size()  < 3) {
            return false;
        }
        // check if closing the currently drawn line produces a valid ring:
        return makeRing().isValid();    
    }
    
    /**
     * Create a ring form the currently drawn line by adding a 
     * segment from the last to the first point.
     * 
     * @return 
     */
    private LinearRing makeRing() {
        int len = coords.size() + 1;
        Coordinate[] coordArray = coords.toArray(new Coordinate[len]);
        coordArray[len - 1] = coordArray[0]; // close the ring
        CoordinateSequence coordSequence = new CoordinateArraySequence(coordArray);
        return new LinearRing(coordSequence, geometryFactory);
    }
    
    @Override
    public boolean finish() {
        LinearRing ring = makeRing();
        if (ring.isValid()) {
            // create the polygon
            Polygon polygon = new Polygon(ring, null, geometryFactory);
            layer.setGeometry(polygon);
            // TODO:  save (cookie is in node lookup via dataobject)
            cleanup();
            return true;
        }
        return false;
    }
    
    @Override
    public DrawingRenderer getRenderer() {
        return new PolygonDrawingRenderer(coords);
    }

    @Override
    public String getDescription() {
        return Bundle.PolygonDrawingContext_description(layer.getName());
    }
    
}
