/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.map.cache;

import java.net.URI;

/**
 * Translate UIR of requested Tile to {@link TileCacheInfo}, where information are stored
 *
 * @author Frantisek Post
 */
public class CacheUriTranslator {

    public static final String TILE_EXTENSION = ".png";
    public static final String FILE_NAME_FORMAT = "%dx%d" + TILE_EXTENSION;
    
    private CacheUriTranslator() {
    }
    
    public static synchronized TileCacheInfo getCacheInfo(URI uri) {
        assert uri != null;
        
        String path = uri.getPath();
        
        if (path != null && path.endsWith(TILE_EXTENSION)) {
            if (path.startsWith("/")) {
                path = path.substring(1); //remove slash
            }
            String xyZoom = path.substring(0, path.indexOf(TILE_EXTENSION));
            String[] coordinates = xyZoom.split("/");
            if (coordinates != null && coordinates.length == 3) {
                int zoom = Integer.parseInt(coordinates[0]);
                int x = Integer.parseInt(coordinates[1]);
                int y = Integer.parseInt(coordinates[2]);
                return new TileCacheInfo(zoom, x, y);
            } else {
                return null;
            }
        } else {
            return null;
        }
    }
    
}
