/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.map.cache;


/**
 * Transfer object with information about {@link Tile}
 * 
 * @author Frantisek Post
 */
public class TileCacheInfo {
    
    private int zoom;
    private int x;
    private int y;
    private String path;
    
    public TileCacheInfo(int zoom, int x, int y) {
        this.zoom = zoom;
        this.x = x;
        this.y = y;
        path = getFileName(x, y);
    }
    
    private String getFileName(int x, int y) {
        return String.format(CacheUriTranslator.FILE_NAME_FORMAT, x, y);
    }

    public int getX() {
        return x;
    }

    public int getY() {
        return y;
    }

    public int getZoom() {
        return zoom;
    }

    /**
     * returns only filename, without zoom directory.
     * <p>
     * This is because I need to create file with this name and don't want to parse it again to separate directory and filename
     * </p>
     * @return 
     */
    public String getPath() {
        return path;
    }
    
}
