/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.geoviewer.jxmap.map.cache.spi;

import java.awt.image.BufferedImage;
import nl.cloudfarming.client.geoviewer.jxmap.map.cache.TileCacheInfo;

/**
 *
 * @author Frantisek Post
 */
public class DefaultTileService extends AbstractTileService {

    private static final int HITS_TO_CLEAN_CACHE = 30; //every 30th write to disk trigger clean of cache
    private int hitCounter = 0;
    private static DefaultTileService instance = new DefaultTileService();
    
    private DefaultTileService() {
    }
    
    @Override
    protected void writeCallback() {
        super.writeCallback();
        if (!CacheCleaner.getInstance().isUnlimited()) {
            hitCounter++;
            if (hitCounter >= HITS_TO_CLEAN_CACHE) {
                hitCounter = 0;
                CacheCleaner.getInstance().run();
            }
        }
    }
    
    //API
    
    @Override
    public boolean contains(TileCacheInfo tileCacheInfo) {
        return CacheManager.getInstance().isCached(tileCacheInfo.getZoom(), tileCacheInfo.getX(), tileCacheInfo.getY());
    }

    @Override
    public BufferedImage getTile(TileCacheInfo tileCacheInfo) {
        return readImage(tileCacheInfo);
    }
    
    public void writeTile(TileCacheInfo tileCacheInfo, BufferedImage image) {
        writeImage(tileCacheInfo, image);
    }
    
    public static DefaultTileService getInstance() {
        return instance;
    }

}
